#[non_exhaustive]pub enum LineItem {
Text(TextSegment),
MultilingualText(MultilingualTextSegment),
Tab {
width: f64,
leader: Option<TextSegment>,
},
Image {
width: f64,
height: f64,
media_id: MediaId,
},
Group {
width: f64,
height: f64,
baseline: Option<f64>,
group: GroupElement,
},
Figure {
item: Box<LineItem>,
alternate_text: String,
structure_id: Option<StructureId>,
},
Marker(TextSegment),
}Expand description
A single item positioned on a line.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Text(TextSegment)
MultilingualText(MultilingualTextSegment)
A validated script, font, and bidi-level text span.
Tab
Fields

leader: Option<TextSegment>Pre-shaped leader text to fill the tab gap (e.g., dots, hyphens).
Image
Group
Fields

group: GroupElementFigure
An informative drawing carried to a semantic output container.
Marker(TextSegment)
Implementations