pub struct Transform {
pub a: f64,
pub b: f64,
pub c: f64,
pub d: f64,
pub e: f64,
pub f: f64,
}Expand description
A 2x3 affine transform using the PDF matrix coefficient order.
Points are transformed as x' = a*x + c*y + e and
y' = b*x + d*y + f.
Fields
a: f64b: f64c: f64d: f64e: f64f: f64Implementations
Sourceimpl Transform
impl Transform
Sourcepub fn rotate_about(degrees: f64, cx: f64, cy: f64) -> Transform
pub fn rotate_about(degrees: f64, cx: f64, cy: f64) -> Transform
Return a rotation in degrees about (cx, cy).
Sourcepub fn then(self, next: Transform) -> Transform
pub fn then(self, next: Transform) -> Transform
Compose two transforms, applying self first and next second.
Sourcepub fn is_identity(self) -> bool
pub fn is_identity(self) -> bool
Return whether all six coefficients exactly equal the identity.
Sourcepub fn transform_rect_bbox(self, rect: Rect) -> Rect
pub fn transform_rect_bbox(self, rect: Rect) -> Rect
Return the axis-aligned bounds of the four transformed corners.